/*  $Id: TestCrypto.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package test;

import net.eduvax.util.App;
import net.eduvax.util.Crypto;
import org.junit.*;
import static org.junit.Assert.*;

public class TestCrypto {
	private Crypto _crypto;
	private Crypto _cryptoBis;
	@Before public void setUp() {
		App.init();
		_crypto=new Crypto("12345");
		_cryptoBis=new Crypto("6789");
	}
	@After public void tearDown() {
		
	}
	
	@Test public void testReversibleCrypt() {
		for (String msg: MSG) {
			String crypt=_crypto.reversibleCrypt(msg);
			String crypt2=_crypto.reversibleCrypt(msg);
			String decrypt=_crypto.uncrypt(crypt);
			String decrypt2=_crypto.uncrypt(crypt2);
			App.TRACE("testReversibleCrypt: "+msg+" -> "+crypt+" / "+crypt2+" -> "+decrypt);
			assertFalse(msg.equals(crypt));
			assertTrue(msg.equals(decrypt));
			assertFalse(crypt.equals(crypt2));
			assertTrue(msg.equals(decrypt2));
		}
	}

	@Test public void testNonReversCrypt() {
		for (String msg: MSG) {
			String crypt1=_crypto.nonReversCrypt(msg);
			String crypt2=_crypto.nonReversCrypt(""+msg);
			String crypt3=_crypto.nonReversCrypt(msg+" ");
			String crypt4=_cryptoBis.nonReversCrypt(msg);
			App.TRACE("testNonReversibleCrypt: "+msg+" -> "+crypt1+" / "+crypt4+" -> "+crypt3);
			assertTrue(crypt1.equals(crypt2));
			assertFalse(crypt1.equals(crypt3));
			assertFalse(crypt1.equals(crypt4));
			int len=crypt1.length()/2;
			assertFalse(crypt1.substring(0,len).equals(crypt3.substring(0,len)));
		}
	}

	@Test public void testBase64() {
		for (String msg: MSG) {
			String crypt=Crypto.base64Encode(msg.getBytes());
			String decrypt=new String(Crypto.base64Decode(crypt));
			App.TRACE("testBase64: "+msg+" -> "+crypt+" -> "+decrypt);
			assertFalse(msg.equals(crypt));
			assertTrue(msg.equals(decrypt));
		}
	}
	private final static String[] MSG={
			"1",
			"12",
			"123",
			"1234",
			"12345",
			"123456",
			"1234567",
			"12345678",
			"123456789",
			"1234567890",
			"12345678901",
			"123456789012345",
			"12345678901234567890",
			"1234567890123456789012345",
			"message  crypter",
			"une phrase avec des accents : ",
			"autre caractres : #|`*!",
			"EADS Astrium",
			"waluigi",
			"wario",
			"wizard"
            };
}
